@@ -1,9 +1,9 @@
 #' @details This function requires a character string as the input
 #'
-#' @description Get login information for a single login 
-#' 
+#' @description Get login information for a single login
+#'
 #' @title Get Login Information for a Single Login
-#' 
+#'
 #' @param login Login to get information about
 #'
 #' @importFrom jsonlite toJSON
@@ -16,20 +16,25 @@
 #' @examples
 #' \dontrun{
 #' login_info<- GetLogin('login-name')
-#' 
+#'
 #' }
 
 GetLogin<- function(login) {
-  
+
   request.body <- c()
   request.body$login <- unbox(login)
 
-  
+  #Hack in locale, every method calls ApiRequest so this hopefully works
+  #Set encoding to utf-8 as well; if someone wanted to do base64 they are out of luck
+  request.body$locale <- unbox(AdobeAnalytics$SC.Credentials$locale)
+  request.body$elementDataEncoding <- unbox("utf8")
+
+
   response <- ApiRequest(body=toJSON(request.body),func.name="Permissions.GetLogin")
 
   temp_df <- as.data.frame(lapply(response[1:11], function (x) ifelse(is.null(x), "", x)))
   temp_df$group_names <- paste(response[[12]], collapse = ',')
-  
+
   return(temp_df)
 
 }
\ No newline at end of file
