@@ -3,23 +3,23 @@
 #' only 5 elements as in the Adobe Reports & Analytics interface.
 #'
 #' Because of the Reporting API structure, this function first requests the
-#' report, then checks the reporting queue to see if the report is completed, 
-#' and when the report returns as "done" pulls the report from the API. This 
+#' report, then checks the reporting queue to see if the report is completed,
+#' and when the report returns as "done" pulls the report from the API. This
 #' checking process will occur up to the specified number of times (default 120),
 #' with a delay between status checks (default 5 seconds). If the report does not
-#' return as "done" after the number of tries have completed, the function will return 
+#' return as "done" after the number of tries have completed, the function will return
 #' an error message.
-#' 
-#' Note: Because of the multiple argument type ("top" and "start" OR "selected"), 
-#' keyword arguments are generally needed towards the end of the function call 
+#'
+#' Note: Because of the multiple argument type ("top" and "start" OR "selected"),
+#' keyword arguments are generally needed towards the end of the function call
 #' instead of just positional arguments.
 #'
-#' @description A QueueTrended report is a report where a single metric is 
+#' @description A QueueTrended report is a report where a single metric is
 #' retrieved, broken down by an element such as page, eVar, prop, etc. and with
 #' a time component. Within the 'element' list, either the "Top X" number of
 #' elements can be received or you can specify the specific elements you are
 #' interested in (such as 3 specific page names).
-#' 
+#'
 #' @title Run a Trended Report
 #'
 #' @param reportsuite.id Report suite id
@@ -47,12 +47,12 @@
 #' @importFrom jsonlite toJSON unbox
 #'
 #' @return Data frame
-#' 
+#'
 #' @examples
 #' \dontrun{
-#' report.data <- QueueTrended("your_report_suite", 
+#' report.data <- QueueTrended("your_report_suite",
 #'                             "2014-01-01",
-#'                             "2014-01-07", 
+#'                             "2014-01-07",
 #'                             c("visits","uniquevisitors","pageviews","event10"),
 #'                             c("page","geoCountry","geoCity")
 #'                             )
@@ -61,10 +61,10 @@
 
 QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
                         top=0,start=0,selected=c(),search=c(),search.type='or',
-                        date.granularity='day', segment.id='', segment.inline='', classification = character(0), 
+                        date.granularity='day', segment.id='', segment.inline='', classification = character(0),
                         anomaly.detection=FALSE, data.current=FALSE, expedite=FALSE,
                         interval.seconds=5,max.attempts=120,validate=TRUE) {
-  
+
   if(anomaly.detection==TRUE && length(elements)>1) {
     print("Warning: Anomaly detection will not be used, as it only works for a single element.")
     anomaly.detection <- FALSE
@@ -83,19 +83,25 @@ QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
   report.description$reportDescription$dateTo <- unbox(date.to)
   report.description$reportDescription$reportSuiteID <- unbox(reportsuite.id)
   report.description$reportDescription$dateGranularity <- unbox(date.granularity)
+
+  #Hack in locale, every method calls ApiRequest so this hopefully works
+  #Set encoding to utf-8 as well; if someone wanted to do base64 they are out of luck
+  report.description$reportDescription$locale <- unbox(AdobeAnalytics$SC.Credentials$locale)
+  report.description$reportDescription$elementDataEncoding <- unbox("utf8")
+
   if(segment.inline!="") {
     report.description$reportDescription$segments <- list(segment.inline)
   }
-  if(segment.id!="") { 
-    report.description$reportDescription$segment_id <- unbox(segment.id) 
+  if(segment.id!="") {
+    report.description$reportDescription$segment_id <- unbox(segment.id)
   }
-  if(anomaly.detection==TRUE) { 
-    report.description$reportDescription$anomalyDetection <- unbox(anomaly.detection) 
+  if(anomaly.detection==TRUE) {
+    report.description$reportDescription$anomalyDetection <- unbox(anomaly.detection)
   }
-  if(data.current==TRUE) { 
-    report.description$reportDescription$currentData <- unbox(data.current) 
+  if(data.current==TRUE) {
+    report.description$reportDescription$currentData <- unbox(data.current)
   }
-  if(expedite==TRUE) { 
+  if(expedite==TRUE) {
     report.description$reportDescription$expedite <- unbox(expedite)
   }
   report.description$reportDescription$metrics = data.frame(id = metrics)
@@ -107,18 +113,18 @@ QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
     i <- i + 1
     # we only put selected, search, top and startingWith for the first element
     if(i==1){
-      working.element <- list(id = unbox(element), 
-                              top = unbox(top[1]), 
+      working.element <- list(id = unbox(element),
+                              top = unbox(top[1]),
                               startingWith = unbox(start))
-      
+
       if(length(selected)!=0){
         working.element[["selected"]] <- selected
       }
       if(length(search)!=0){
-        working.element[["search"]] <- list(type = unbox(search.type), 
+        working.element[["search"]] <- list(type = unbox(search.type),
                                             keywords = search)
       }
-      
+
     } else {
    	  # Check if the input is a vector with more than 1 element
       if(length(top)>=i){
@@ -128,11 +134,11 @@ QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
       	working.element <- list(id = unbox(element), top = unbox("50000"))
       }
     }
-    
+
     if(length(classification)>=i){
       working.element[["classification"]] <- unbox(classification[i])
     }
-    
+
     if(length(elements.formatted)>0) {
       elements.formatted <- append(elements.formatted,list(working.element))
     } else {
@@ -143,6 +149,6 @@ QueueTrended <- function(reportsuite.id, date.from, date.to, metrics, elements,
 
   report.data <- SubmitJsonQueueReport(toJSON(report.description),interval.seconds=interval.seconds,max.attempts=max.attempts,validate=validate)
 
-  return(report.data) 
+  return(report.data)
 
-}  
+}
