@@ -11,6 +11,7 @@
 #' @param report.description JSON report description
 #' @param interval.seconds How long to wait between attempts
 #' @param max.attempts Number of API attempts before stopping
+#' @param validate Weather to submit report definition for validation before requesting the data.
 #'
 #' @importFrom jsonlite toJSON unbox
 #'
@@ -26,19 +27,21 @@
 #' @export
 #'
 
-SubmitJsonQueueReport <- function(report.description,interval.seconds=5,max.attempts=120) {
+SubmitJsonQueueReport <- function(report.description,interval.seconds=5,max.attempts=120,validate=TRUE) {
 
-  if(!ValidateReport(report.description)) {
-    stop("ERROR: Invalid report description.")
+  # Determine if we should validate the definition
+  if(validate) {
+    if(!ValidateReport(report.description)) {
+      stop("ERROR: Invalid report description.")
+    }
   }
-
+  
   response <- ApiRequest(body=report.description,func.name="Report.Queue")
   
   #If response returns an error, return error message. Else, continue with capturing report ID
-  if(!is.numeric(response$reportID)) {
+  report.id <- as.numeric(response$reportID)
+  if(!is.numeric(report.id)) {
     stop("ERROR: the API validated the report, but did not return a report ID")
-  } else {
-    report.id <- response$reportID
   }
 
   request.body <- c()
@@ -70,4 +73,4 @@ SubmitJsonQueueReport <- function(report.description,interval.seconds=5,max.atte
 
   return(report.parsed)
 
-}
\ No newline at end of file
+}
